package com.ruoyi.tcZz.controller;

import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.core.page.TableDataInfo;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.tcZz.domain.TcWljgtj;
import com.ruoyi.tcZz.domain.TcYqzs;
import com.ruoyi.tcZz.domain.TcYtlc;
import com.ruoyi.tcZz.service.ITcYtlcService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;

import javax.servlet.http.HttpServletResponse;
import java.util.List;

/**
 * 约谈流程Controller
 *
 * @author ruoyi
 * @date 2023-10-13
 */
@RestController
@Api(tags = "约谈流程")
@RequestMapping("/tcZz/netManage/ytlc")
public class TcYtlcController extends BaseController {
    @Autowired
    private ITcYtlcService tcYtlcService;

    /**
     * 查询约谈流程列表
     */
    @ApiOperation(value = "查询约谈流程列表", response = TcYtlc.class)
    @GetMapping("/list")
    public TableDataInfo list(TcYtlc tcYtlc) {
        startPage();
        List<TcYtlc> list = tcYtlcService.selectTcYtlcList(tcYtlc);
        return getDataTable(list);
    }

    /**
     * 导出约谈流程列表
     */
    @ApiOperation(value = "导出约谈流程列表")
    @PostMapping("/export")
    public void export(HttpServletResponse response, TcYtlc tcYtlc) {
        List<TcYtlc> list = tcYtlcService.selectTcYtlcList(tcYtlc);
        ExcelUtil<TcYtlc> util = new ExcelUtil<TcYtlc>(TcYtlc.class);
        util.exportExcel(response, list, "约谈流程数据");
    }

    /**
     * 获取约谈流程详细信息
     */
    @ApiOperation(value = "获取约谈流程详细信息")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id) {
        return success(tcYtlcService.selectTcYtlcById(id));
    }

    /**
     * 新增约谈流程
     */
    @ApiOperation(value = "新增约谈流程")
    @PostMapping
    public AjaxResult add(@RequestBody TcYtlc tcYtlc) {
        return toAjax(tcYtlcService.insertTcYtlc(tcYtlc));
    }

    /**
     * 修改约谈流程
     */
    @ApiOperation(value = "修改约谈流程")
    @PutMapping
    public AjaxResult edit(@RequestBody TcYtlc tcYtlc) {
        return toAjax(tcYtlcService.updateTcYtlc(tcYtlc));
    }

    /**
     * 删除约谈流程
     */
    @ApiOperation(value = "删除约谈流程")
    @DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids) {
        return toAjax(tcYtlcService.deleteTcYtlcByIds(ids));
    }


    /**
     * 导入
     */
    @ApiOperation("通用导入excel信息")
    @PostMapping("/common/importExcel")
    public AjaxResult importExcel(MultipartFile file) throws Exception {
        ExcelUtil<TcYtlc> util = new ExcelUtil<TcYtlc>(TcYtlc.class);
        List<TcYtlc> tcYtlcList = util.importExcel(file.getInputStream());
        tcYtlcService.importUser(tcYtlcList);
        return AjaxResult.success();
    }
    /**
     * 批量启用禁用
     *
     * @param isStatus 启用禁用状态
     * @return
     */

    @ApiOperation("批量启用禁用")
    @GetMapping("/isStatus")
    public AjaxResult isStatus(@RequestParam("isStatus") Integer isStatus,@RequestParam("ids") List<String> ids) {
        tcYtlcService.updateByisStatus(isStatus,ids);
        return AjaxResult.success();
    }

    @ApiOperation("通用下载excel模板")
    @PostMapping("/importTemplate")
    public void importTemplate(HttpServletResponse response)
    {
        ExcelUtil<TcYtlc> util = new ExcelUtil<TcYtlc>(TcYtlc.class);
        util.importTemplateExcel(response, " 约谈流程");
    }
}
